"""
    BasisTheory Vault API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import unittest

import basistheory
from basistheory.api.token_children_api import TokenChildrenApi  # noqa: E501


class TestTokenChildrenApi(unittest.TestCase):
    """TokenChildrenApi unit test stubs"""

    def setUp(self):
        self.api = TokenChildrenApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_association(self):
        """Test case for create_association

        """
        pass

    def test_create_child(self):
        """Test case for create_child

        """
        pass

    def test_delete_association(self):
        """Test case for delete_association

        """
        pass

    def test_get_children(self):
        """Test case for get_children

        """
        pass


if __name__ == '__main__':
    unittest.main()
